@@ -40,7 +40,7 @@ class mNotes(object):
 
   __pretty_app_name__ = "mNotes"
   __app_name__ = "mNotes"
-  __version__ = "0.3.3"
+  __version__ = "0.3.4"
   __context__ = "net.khertan.mnotes"
 
   _glade_files = [
@@ -219,12 +219,16 @@ class mNotes(object):
         pass
 
   def _load_current_note_draw(self):
+    print 'debug 1'
     if self._current_note.have_draw == True:
 #      self._drawview.show()
       pixbuf = gtk.gdk.pixbuf_new_from_file(self._current_note.get_draw_path())
+      print 'debug 2'
       if pixbuf == None:
         pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 600, 400)
+        print 'debug 3'
       try:
+        print 'debug 4'
 #        self._drawview.window.draw_pixbuf(None,pixbuf,0,0,0,0)
         self.pixmap,_ = pixbuf.render_pixmap_and_mask()
 #        self.pixmap.draw_rectangle(self._drawview.get_style().white_gc, True,0, 0, 600, 400)
@@ -232,21 +236,25 @@ class mNotes(object):
         del pixbuf
         self._current_note.draw_loaded = True
       except StandardError,e:
+        print 'debug 5'
         print e
         self._current_note.draw_loaded = False
         pass
     else:
+      print 'debug 6'
       self._current_note.draw_loaded = False
       pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 600, 400)
       try:
         #self._drawview.window.draw_pixbuf(None,pixbuf,0,0,0,0)
         self.pixmap,_ = pixbuf.render_pixmap_and_mask()
         self.pixmap.draw_rectangle(self._drawview.get_style().white_gc, True,0, 0, 600, 400)
-        self._drawview.set_size_request(-1,-1)
+        #self._drawview.queue_draw()
         del pixbuf
+        print 'debug 7'
         self._current_note.draw_loaded = True
       except StandardError,e:
         print e
+        print 'debug 8'
         self._current_note.draw_loaded = False
         pass
 
@@ -396,6 +404,8 @@ class mNotes(object):
 
   def _add_draw_note(self,widget):
     self._add_note(1)
+#    self._load_current_note_draw()
+    self._drawview.queue_draw()
 
   def _add_pict_note(self,widget):
     self._add_note(2)
